We ship some third-party things with Nikola.  They live here, along with their licenses.

Packages:

 * tzlocal by Lennart Regebro, CC0 license (modified to remove pytz dependency)
 * datecond by Chris Warrick (Nikola contributor), 3-clause BSD license
   (modified)
 * pygments_better_html by Chris Warrick (Nikola contributor), 3-clause BSD license,
   portions copyright the Pygments team (2-clause BSD license).

